Changelog
=========

Current (2025-06-26)
--------------------


0.0.4 (2024-06-26)
------------------

* Fixed metadata storing
* Fixed metadata stored in bytes so that actualy data is actually stored


0.0.3 (2024-06-19)
------------------

* Added script with an entrypoint for running the conversion tool from the command line
* Added hit calculation on root files
* Added header as metadata for feather and parquet files
* Added header as metadata for root files
* Added example sensor specs to the sensor hitmaps for future documentation


0.0.2 (2024-06-19)
------------------

* Added SAMPIC binary decoding
* Added some tools to handle hits and sensor hitmaps
* First code release on PyPI.


0.0.1 (2024-06-19)
------------------

* Test empty release
